Re: Kolab3 on Mageia update

Thomas Spuhler <[email protected]>
Newsgroups gmane.comp.kde.devel.kolab
Message-ID <201212271954.27411.thomas__19049.726779531$1356663298$gmane$org@btspuhler.com>
On Sunday, December 23, 2012 03:26:39 AM Jeroen van Meeuwen (Kolab Systems) wrote:
> On 2012-12-22 19:39, Thomas Spuhler wrote:
> > Here is the snippet that could give a hint. (is this message normal:
> > The port number '389' is not available for use.)
> 
> That's not a normal message - you are running some different LDAP
> server that is getting in the way of the new LDAP server.
> 
> Kind regards,
> 
> Jeroen van Meeuwen

Almost success. It went through the complete setup, with (I believe) minor error, but one stood out:

# systemctl status wallace.service
wallace.service - Wallace Content Filter
          Loaded: loaded (/usr/lib/systemd/system/wallace.service; enabled)
          Active: failed (Result: exit-code) since Thu, 2012-12-27 19:37:52 MST; 2min 55s ago
          CGroup: name=systemd:/system/wallace.service

Dec 27 19:37:52 vbox.btspuhler.com wallaced[23123]: wallace = wallace.WallaceDaemon()
Dec 27 19:37:52 vbox.btspuhler.com wallaced[23123]: File "/usr/lib/python2.7/site-
packages/wallace/__init__.py", line 125, in __init__
Dec 27 19:37:52 vbox.btspuhler.com wallaced[23123]: conf.process_groupname
Dec 27 19:37:52 vbox.btspuhler.com wallaced[23123]: File "/usr/lib/python2.7/site-
packages/pykolab/utils.py", line 154, in ensure_directory
Dec 27 19:37:52 vbox.btspuhler.com wallaced[23123]: os.makedirs(_dir)
Dec 27 19:37:52 vbox.btspuhler.com wallaced[23123]: File "/usr/lib64/python2.7/os.py", line 157, in 
makedirs
Dec 27 19:37:52 vbox.btspuhler.com wallaced[23123]: mkdir(name, mode)
Dec 27 19:37:52 vbox.btspuhler.com wallaced[23123]: OSError: [Errno 13] Permission denied: 
'/var/run/wallaced'
Dec 27 19:37:52 vbox.btspuhler.com systemd[1]: Failed to start Wallace Content Filter.

I fooled around for ever with the problem could not find ldap schema.

I finally made a patch (attached) and rebulit the pykolab package.

I made the changes to have the correct location in the 
/usr/lib/python2.7/site-packages/pykolab/setup/setup_ldap.py but it didn't have any influence

According the the manual, if the . py file is newer than the .pyc then it should remake the .pyc file.

-- 
Best regards
Thomas Spuhler

_______________________________________________
Kolab-devel mailing list
[email protected]
https://www.intevation.de/mailman/listinfo/kolab-devel
mga-schema-loc.patch (text/x-patch, 1.6 KB)
diff -ur pykolab-0.5.10/pykolab/setup/setup_ldap.py pykolab-0.5.10-mga/pykolab/setup/setup_ldap.py
--- pykolab-0.5.10/pykolab/setup/setup_ldap.py	2012-12-25 03:57:27.000000000 -0700
+++ pykolab-0.5.10-mga/pykolab/setup/setup_ldap.py	2012-12-26 20:52:34.000000000 -0700
@@ -115,7 +115,7 @@
             pw = pwd.getpwnam("dirsrv")
         except:
             _input['userid'] = utils.ask_question(_("User"), default="nobody")
-            _input['group'] = utils.ask_question(_("Group"), default="nobody")
+            _input['group'] = utils.ask_question(_("Group"), default="nogroup")
         else:
             _input['userid'] = utils.ask_question(_("User"), default="dirsrv")
             _input['group'] = utils.ask_question(_("Group"), default="dirsrv")
@@ -127,7 +127,7 @@
             pw = pwd.getpwnam("dirsrv")
         except:
             _input['userid'] = "nobody"
-            _input['group'] = "nobody"
+            _input['group'] = "nogroup"
         else:
             _input['userid'] = "dirsrv"
             _input['group'] = "dirsrv"
@@ -282,9 +282,9 @@
     # TODO: When fail, fail gracefully.
 
     # Find the kolab schema. It's installed as %doc in the kolab-schema package.
     # TODO: Chown nobody, nobody, chmod 440
     schema_file = None
-    for root, directories, filenames in os.walk('/usr/share/doc/'):
+    for root, directories, filenames in os.walk('/usr/share/doc/kolab-schema/'):
         for filename in filenames:
             if filename.startswith('kolab') and filename.endswith('.ldif') and schema_file == None:
                 schema_file = os.path.join(root,filename)
signature.asc (application/pgp-signature, 198 B)
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.11 (GNU/Linux)

iEYEABECAAYFAlDdCeMACgkQjsMgV2ARTmOQGgCfX/dINL1X08xiFiGWAmFoAnNu
V8MAnREgwidYHdiHoSWx7ptYhJQhqaiC
=kOkH
-----END PGP SIGNATURE-----
@@ -282,9 +282,9 @@
 
     # Find the kolab schema. It's installed as %doc in the kolab-schema package.
-    # TODO: Chown nobody, nobody, chmod 440
+    # TODO: Chown nobody, nogroup, chmod 440
     schema_file = None
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.